@@ -9,9 +9,9 @@ import logging, json, uuid
 from flask.globals import current_app
 from trexlib.utils.google.bigquery_util import create_bigquery_client, stream_data_by_datetime_partition, stream_data
 from trexanalytics import conf as analytics_conf
-from trexanalytics.bigquery_table_template_config import REGISTERED_CUSTOMER_TEMPLATE, MERCHANT_REGISTERED_CUSTOMER_TEMPLATE
+from trexanalytics.bigquery_table_template_config import CUSTOMER_TRANSACTION_TEMPLATE, MERCHANT_REGISTERED_CUSTOMER_TEMPLATE
 from trexmodel.models.datastore.analytic_models import UpstreamData
-from trexmodel.utils.model.model_util import create_db_client 
+from trexmodel.utils.model.model_util import create_db_client
 from datetime import datetime
 from trexlib.utils.log_util import get_tracelog
 from trexanalytics.controllers.importdata.import_data_base_routes import TriggerImportDataBaseResource, InitImportDataBaseResource, ImportDataBaseResource
